@@ -17,7 +17,7 @@ def timer(time_length = False, message = False, variable = False):
     if completed_message:
       print(completed_message)
     if variable:
-      file = open("Timer_Completed", "w")
+      file = open(variable, "w")
       file.write("True")
       file.close()
   t = threading.Thread(target=sub_timer)
